@@ -12,7 +12,7 @@ import dotenv
 from .build import detect_unity, build_def, unity, build_data
 from . import steps, config
 
-VERSION = "v0.0.1"
+VERSION = "v0.0.2"
 
 
 @dataclass
@@ -47,6 +47,12 @@ def toriicli(ctx, project_path):
         cfg = config.from_yaml(config.CONFIG_NAME)
         if cfg is None:
             raise SystemExit(1)
+
+        # if the project path is not absolute, we need to make it so, as
+        # Unity expects it to be absolute
+        if not path.isabs(project_path):
+            project_path = path.abspath(project_path)
+
         ctx.obj = ToriiCliContext(cfg, cfg.actual_project_dir or project_path)
 
 
